Learn R Programming

FlexReg (version 1.1)

Atomic: Atomic bombs data

Description

Counts of chromosome aberrations in atomic bombs survivors.

Arguments

Format

A data frame containing 1039 observations on the following 4 variables.

y

the number of cells with chromosomal abnormalities.

n

the number of analyzed cells. It is fixed to 100 for all the observations.

dose

a quantitative measure of the radiation exposure level, expressed in rads.

bomb

a factor, indicating which bomb the subject survived (H = Hiroshima, N = Nagasaki).

Details

The data has been originally analyzed by Otake and Prentice (1984) and successively by Ascari and Migliorati (2021).

References

Otake, M., Prentice, R.L. (1984). The analysis of chromosomally aberrant cells based on beta-binomial distribution. Radiat Res. 98, 456--470.

Ascari, R., Migliorati, S. (2021). A new regression model for overdispersed binomial data accounting for outliers and an excess of zeros. Statistics in Medicine, 40(17), 3895--3914. doi:10.1002/sim.9005