Learn R Programming

FlexReg (version 1.1)

Bacteria: Bacteria data

Description

Counts of eggs parasitized by female parasitoids.

Arguments

Format

A data frame containing 70 observations on the following 4 variables.

y

the total number of parasitized eggs.

n

the maximum number of eggs that female parasitoids could parasitized. It is fixed to 128 for all the observations.

females

the number of female parasitoids.

females_std

the standardized version of females.

Details

The data has been originally analyzed by Demétrio et al (2014) and successively by Ascari and Migliorati (2021). Data come from a completely randomized experiment with 10 replicates for each specification of number of females.

References

Demétrio, C.G.B., Hinde, J., Moral, R.A. (2014). Models for overdispersed data in entomology. Ecological Modelling Applied to Entomology. Entomology in Focus Switzerland: Springer International Publishing; 219- 259.

Ascari, R., Migliorati, S. (2021). A new regression model for overdispersed binomial data accounting for outliers and an excess of zeros. Statistics in Medicine, 40(17), 3895--3914. doi:10.1002/sim.9005