dVIB: Variance-inflated beta probability density function
Description
The function computes the probability density function of the variance-inflated beta distribution.
It can also compute the probability density function of the augmented variance-inflated beta distribution by assigning positive probabilities to zero and one and a (continuous) variance-inflated beta density to the interval (0,1).
Usage
dVIB(x, mu, phi, p, k, q0 = NULL, q1 = NULL)
Value
A vector with the same length as x.
Arguments
x
a vector of quantiles.
mu
the mean parameter of the variance-inflated beta distribution. It must lie in (0, 1).
phi
the precision parameter of the variance-Inflated distribution. It must be a positive real value.
p
the mixing weight. It must lie in (0, 1).
k
the extent of the variance inflation. It must lie in (0, 1).
q0
the probability of augmentation in zero. It must lie in (0, 1). In case of no augmentation is NULL (default).
q1
the probability of augmentation in one. It must lie in (0, 1). In case of no augmentation is NULL (default).
Details
The VIB distribution is a special mixture of two beta distributions with density
$$f_{VIB}(x;\mu,\phi,p,k)=p f_B(x;\mu,\phi k)+(1-p)f_B(x;\mu,\phi)$$
for \(0<x<1\), where \(f_B(x;\cdot,\cdot)\) is the beta density with a mean-precision parameterization.
Moreover, \(0<p<1\) is the mixing weight, \(0<\mu<1\) represents the overall (as well as mixture component)
mean, \(\phi>0\) is a precision parameter, and \(0<k<1\) determines the extent of the variance inflation.
The augmented VIB distribution has density
\(q_0\), if \(x=0\)
\(q_1\), if \(x=1\)
\((1-q_0-q_1)f_{VIB}(x;\mu,\phi,p,k)\), if \(0<x<1\)
where \(0<q_0<1\) identifies the augmentation in zero, \(0<q_1<1\) identifies the augmentation in one,
and \(q_0+q_1<1\).
References
Di Brisco, A. M., Migliorati, S., Ongaro, A. (2020). Robustness against outliers: A new variance inflated regression model for proportions. Statistical Modelling, 20(3), 274--309.
doi:10.1177/1471082X18821213