an object of class `flexreg`, usually the result of flexreg or flexreg_binom.
name.x
a character containing the name of the covariate from the mean model to be plotted on the x-axis of the scatterplot.
additional.cov.default
a list of additional covariates from the mean model to be set as default.
...
additional arguments. Currently not used.
Details
The function produces a scatterplot of the covariate from the mean model specified in name.x and y or y/n if the response is continuous bounded or binomial, respectively. Any other variable specified in the mean model must be set to a default through the additional.cov.default argument.
If the regression model is of FB without augmentation or FBB type the function returns a scatterplot with three curves, one corresponding to the overall mean and two corresponding to the component means of the FB distribution, i.e., \(\lambda_1\) and \(\lambda_2\).