Method for plotting the simulated posterior predictive distribution from an object of class `flexreg_postpred`. The plot shows the posterior predictive interval for each statistical unit.
Additionally, the mean of the posterior predictives and the values of the observed response (either \(y\) or \(y/n\) for bounded or binomial responses, respectively) can be added.
an object of class `flexreg_postpred` containing the simulated posterior predictives, usually the result of posterior_predict.
prob
the interval probability for the posterior predictives (default is 0.9).
p_mean
a logical value indicating whether the posterior predictives' mean should be plotted.
response
a numerical vector containing the response (either \(y\) or \(y/n\) for bounded or binomial responses, respectively) to be added to the plot. If NULL, observed values are not plotted.