the number of observations. If length(n) > 1, the length is taken to be the number required.
size
the total number of trials.
mu
the mean parameter. It must lie in (0, 1).
theta
the overdispersion parameter. It must lie in (0, 1).
phi
the precision parameter. It is an alternative way to specify the theta parameter. It must be a positive real value.
References
Ascari, R., Migliorati, S. (2021). A new regression model for overdispersed binomial data accounting for outliers and an excess of zeros. Statistics in Medicine, 40(17), 3895--3914. doi:10.1002/sim.9005