Bayesian version of R-squared for flexible regression models for continuous bounded or binomial data.
Usage
R2_bayes(model)
Arguments
model
an object of class `flexreg`, usually the result of flexreg or flexreg_binom.
Details
The function provides a Bayesian version of the R-squared measure, defined as the variance of the predicted values divided by itself plus the expected variance of the errors.
References
Andrew Gelman, Ben Goodrich, Jonah Gabry & Aki Vehtari (2019) R-squared for Bayesian Regression Models, The American Statistician, 73:3, 307-309, DOI: 10.1080/00031305.2018.1549100