The function computes the probability density function of the beta distribution with a mean-precision parameterization.
It can also compute the probability density function of the augmented beta distribution by assigning positive probabilities to zero and one and a (continuous) beta density to the interval (0,1).
Usage
dBeta_mu(x, mu, phi, q0 = NULL, q1 = NULL)
Value
A vector with the same length as x.
Arguments
x
a vector of quantiles.
mu
the mean parameter of the beta distribution. It must lie in (0, 1).
phi
the precision parameter of the Beta distribution. It must be a positive real value.
q0
the probability of augmentation in zero. It must lie in (0, 1). In case of no augmentation is NULL (default).
q1
the probability of augmentation in one. It must lie in (0, 1). In case of no augmentation is NULL (default).
Details
The beta distribution has density
$$f_B(x;\mu,\phi)=\frac{\Gamma{(\phi)}}{\Gamma{(\mu\phi)}\Gamma{((1-\mu)\phi)}}x^{\mu\phi-1}(1-x)^{(1-\mu)\phi-1}$$
for \(0<x<1\), where \(0<\mu<1\) identifies the mean and \(\phi>0\) is the precision parameter.
The augmented beta distribution has density
\(q_0\), if \(x=0\)
\(q_1\), if \(x=1\)
\((1-q_0-q_1)f_B(x;\mu,\phi)\), if \(0<x<1\)
where \(0<q_0<1\) identifies the augmentation in zero, \(0<q_1<1\) identifies the augmentation in one,
and \(q_0+q_1<1\).
References
Ferrari, S.L.P., Cribari-Neto, F. (2004). Beta Regression for Modeling Rates and Proportions. Journal of Applied Statistics, 31(7), 799--815. doi:10.1080/0266476042000214501