The function computes the probability density function of the flexible beta distribution.
Usage
dFB(x, mu, phi, p, w)
Value
A vector with the same length as x.
Arguments
x
a vector of quantiles.
mu
the mean parameter. It must lie in (0, 1).
phi
the precision parameter. It must be a positive real value.
p
the mixing weight. It must lie in (0, 1).
w
the normalized distance among clusters. It must lie in (0, 1).
Details
The FB distribution is a special mixture of two beta distributions
$$p Beta(x|\lambda_1,\phi)+(1-p)Beta(x|\lambda_2,\phi)$$
for \(0<x<1\) where \(Beta(x|\cdot,\cdot)\) is the beta distribution with a mean-precision parameterization.
Moreover, \(0<p<1\) is the mixing weight, \(\phi>0\) is a precision parameter,
\(\lambda_1=\mu+(1-p)w\) and \(\lambda_2=\mu-pw\) are the component means of the first and second component of the mixture,
\(0<\mu=p\lambda_1+(1-p)\lambda_2<1\) is the overall mean, and \(0<w<1\) is the normalized distance between clusters.
References
Migliorati, S., Di Brisco, A. M., Ongaro, A. (2018). A New Regression Model for Bounded Responses. Bayesian Analysis, 13(3), 845--872. doi:10.1214/17-BA1079