Learn R Programming

FlexReg (version 1.1)

dVIB: Variance-inflated beta probability density function

Description

The function computes the probability density function of the variance-inflated beta distribution.

Usage

dVIB(x, mu, phi, p, k)

Value

A vector with the same length as x.

Arguments

x

a vector of quantiles.

mu

the mean parameter. It must lie in (0, 1).

phi

the precision parameter. It must be a positive real value.

p

the mixing weight. It must lie in (0, 1).

k

the extent of the variance inflation. It must lie in (0, 1).

Details

The VIB distribution is a special mixture of two beta distributions $$p Beta(x|\mu,\phi k)+(1-p)Beta(x|\mu,\phi)$$ for \(0<x<1\) where \(Beta(x|\cdot,\cdot)\) is the beta distribution with a mean-precision parameterization. Moreover, \(0<p<1\) is the mixing weight, \(0<\mu<1\) represents the overall (as well as mixture component) mean, \(\phi>0\) is a precision parameter, and \(0<k<1\) determines the extent of the variance inflation.

References

Di Brisco, A. M., Migliorati, S., Ongaro, A. (2020) Robustness against outliers: A new variance inflated regression model for proportions. Statistical Modelling, 20(3), 274--309. doi:10.1177/1471082X18821213

Examples

Run this code
dVIB(x = c(.5,.7,.8), mu = 0.3, phi = 20, p = .5, k= .5)

Run the code above in your browser using DataLab