Learn R Programming

FlexReg (version 1.1)

rBeta_mu: Random generator from the beta distribution

Description

The function randomly generates values from the beta distribution with a mean-precision parameterization.

Usage

rBeta_mu(n, mu, phi)

Value

A vector of length n.

Arguments

n

the number of observations. If length(n) > 1, the length is taken to be the number required.

mu

the mean parameter. It must lie in (0, 1).

phi

the precision parameter. It must be a positive real value.

References

Ferrari, S.L.P., and Cribari-Neto, F. (2004). Beta Regression for Modeling Rates and Proportions. Journal of Applied Statistics, 31(7), 799--815. doi:10.1080/0266476042000214501

Examples

Run this code
rBeta_mu(100, mu = 0.5, phi = 30)

Run the code above in your browser using DataLab