Learn R Programming

FlexReg (version 1.1)

rFB: Random generator from the flexible beta distribution

Description

The function randomly generates values from the flexible beta distribution.

Usage

rFB(n, mu, phi, p, w)

Value

A vector of length n.

Arguments

n

the number of observations. If length(n) > 1, the length is taken to be the number required.

mu

the mean parameter. It must lie in (0, 1).

phi

the precision parameter. It must be a positive real value.

p

the mixing weight. It must lie in (0, 1).

w

the normalized distance among clusters. It must lie in (0, 1).

References

Migliorati, S., Di Brisco, A. M., Ongaro, A. (2018). A New Regression Model for Bounded Responses. Bayesian Analysis, 13(3), 845--872. doi:10.1214/17-BA1079

Examples

Run this code
rFB(100,0.5,30,0.3,0.6)

Run the code above in your browser using DataLab